/*======================PROCEDIMENTO CRIA_VENCIMENTO============================
   PROCEDIMENTO CRIA ,A PARTIR DA PARAMETRIZAO DA FORMA DE PAGAMENTO,
   VENCIMENTOS PARA O VALOR DA NOTA FISCAL QUE  PASSADO COMO PARMETRO.
   O PROCEDIMENTO DIFERENCIA FORMAS DE PAGAMENTO DE CLIENTES, FORNECEDORES,
   PEDIDOS E AUTORIZAO DE FORNECIMENTO, DE ACORDO COM A ORIGEM DA NOTA FISCAL.

   OBSERVAO :
      OS VENCIMENTOS GERADOS SERO GRAVADOS EM UMA TABELA TEMPORRIA,
      A TRAB_VENCIMENTO, SENDO QUE ESSAS INFORMAES SERO APAGADAS POSTERIORMENTE
      PELA ROTINA QUE A CHAMOU OU PELO ROLLBACK DA TRANSAO.
   -------
   ENTRADA
   -------
      O PROCEDIMENTO RECEBE OS SEGUINTES PARMETROS DE ENTRADA:
      P_CDFILIAL       : CDIGO DA FILIAL DE LANAMENTO DA NOTA FISCAL
      P_NRLANCTONF     : NMERO DE LANAMENTO DA NOTA FISCAL
      P_IDENTRSAIDOP   : 'E' - NOTA FISCAL DE ENTRADA LANADA PELO MDULO DFE
                         'S' - NOTA FISCAL DE SADA LANADA PELO MDULO DFS
                         'A' - NOTA FISCAL IMPORTADA DE UMA AF
                         'P' - NOTA FISCAL ORIGINADA DA EXPEDIO DE UM PEDIDO
      P_VRPAGTO        : VALOR DA NOTA FISCAL (CONSIDERANDO TODOS OS DESCONTOS)
      P_DTEMISSAO      : DATA DE EMISSO DA NOTA FISCAL
      P_DTENTRSAID     : DATA DE ENTRADA/SADA DA NOTA FISCAL
      P_CDCLIEFORN     : CDIGO DO CLIENTE/FORNECEDOR DA NOTA FISCAL
      P_CDFILIEMIRECE  : CDIGO DA FILIAL DE RECEBIMENTO/EMISSO DA NOTA FISCAL
      P_ORIGDESTNF     : IDENTIFICADOR DE ORIGEM DA NOTA FISCAL
      P_CDFILLANC      : (OPCIONAL)CDIGO DA FILIAL DE LANAMENTO DA AF*
      P_CDFILDEST      : (OPCIONAL)CDIGO DA FILIAL DE DESTINO DA AF*
      P_NRAUTOFORN     : (OPCIONAL)NMERO DA AF
      P_CDFILPEDIDO    : (OPCIONAL)CDIGO DA FILIAL DE LANAMENTO DO PEDIDO**
      P_NRPEDIDO       : (OPCIONAL)NMERO DO PEDIDO**

      * : SOMENTE INFORMADOS PARA NOTA FISCAL ORIUNDA DE AF
      **: SOMENTE INFORMADOS PARA NOTA FISCAL ORIUNDA DA EXPEDIO DE PEDIDOS

   -----
   SADA
   -----
      O PROCEDIMENTO NO POSSUI RETORNO
   ------------------
   MTODOS AUXILIARES
   ------------------
      FORMAPGTOFIXA : DETERMINA O VENCIMENTO A PARTIR DA FORMA FIXA DE PAGAMENTO
      DIAPGTO : DETERMINA O DIA DA SEMANA OU MS EM QUE O VENCIMENTO DEVE CAIR
      FORMAPGTO : DETERMINA A DATA BASE PARA OS VENCIMENTOS
      CONSISTE_FERI_BANC : CORRIGE O VENCIMENTO, CONSIDERANDO O FERIADO BANCRIO
      SET_PARAMETROS : INICIALIZA OS PARMETROS NECESSRIOS PARA
                       GERAO DOS VENCIMENTOS, DATA BASE, QUANTIDADE DE DIAS,
                       FORMA DE PAGAMENTO, ETC

@C:\web_545\sql\end_conv\sqlserver\1061_FINSTPS_CRIA_VENCIMENTO.SQL;

DEBUGAR PROCEDURE
RAISERROR('', 16,1);

*/

IF EXISTS (SELECT
              *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE
              O.NAME = 'CRIA_VENCIMENTO' AND
              TYPE   = 'P'               AND
              U.UID  = O.UID             AND
              U.NAME = USER)

DROP PROCEDURE CRIA_VENCIMENTO
GO

CREATE PROCEDURE CRIA_VENCIMENTO(
          @P_CDFILIAL      VARCHAR(4),
          @P_NRLANCTONF    VARCHAR(10),
          @P_IDENTRSAIDOP  VARCHAR(1),
          @P_VRPAGTO       FLOAT,
          @P_DTEMISSAO     DATETIME,
          @P_DTENTRSAID    DATETIME,
          @P_CDCLIEFORN    VARCHAR(21),
          @P_CDFILIEMIRECE VARCHAR(4),
          @P_ORIGDESTNF    VARCHAR(1),
          @P_CDFILLANC     VARCHAR(4),
          @P_CDFILDEST     VARCHAR(4),
          @P_NRAUTOFORN    VARCHAR(10),
          @P_CDFILPEDIDO   VARCHAR(4),
          @P_NRPEDIDO      VARCHAR(10))
AS
   DECLARE @V_IDFORMAPGTO     VARCHAR(01);
   DECLARE @V_NRPARCPGTO      FLOAT;
   DECLARE @V_IDTIPODTPGT     VARCHAR(4);

   DECLARE @V_COUNT           NUMERIC(15,2);

   DECLARE @V_SEQUENCIAL      FLOAT;
   DECLARE @V_VRPARCVENC      NUMERIC(15,2);
   DECLARE @V_NRPARCELAS      FLOAT;
   DECLARE @V_NRPARCELASST    FLOAT;
   DECLARE @V_VRPARCAUXI      NUMERIC(15,2);
   DECLARE @V_INDIAS          FLOAT;
   DECLARE @V_INGUARDANRDIAS  FLOAT;

   DECLARE @V_DTAUX           DATETIME;
   DECLARE @V_DTVENCIMENTO    DATETIME;
   DECLARE @V_DTBASE          DATETIME;

   DECLARE @V_VRPAGTO         NUMERIC(15,2);

   DECLARE @V_CDSERVCONT      VARCHAR(5);

   DECLARE @V_CODIGO VARCHAR(1);
   DECLARE @V_CDCLIEFORN VARCHAR(21);

   DECLARE @V_IDGERPARCST  VARCHAR(1);
   DECLARE @V_NRDIAPOSEMDOCST FLOAT;

   DECLARE @V_VRTOTIMPONF NUMERIC(15,2);
   DECLARE @V_VRTOTIMPONFPR NUMERIC(15,2);

   DECLARE @V_BOCONSFERIBANC BIT;

   DECLARE @V_IDTPPERIODO VARCHAR(1);

   DECLARE @V_CDFORMPGTO VARCHAR(2);

   DECLARE @V_IDTPFORPGT VARCHAR(1);
   DECLARE @V_IDUTDIAPGT VARCHAR(1);
   DECLARE @V_NRDIAPGFIX FLOAT;

   DECLARE @V_NRDIASPGTO FLOAT;
   DECLARE @V_VRPERCPGTO NUMERIC(15,2);

   DECLARE @V_BOFERIFILI BIT;
   DECLARE @V_NRDIASFERI FLOAT;
   DECLARE @V_DTANTERIOR DATETIME;

   DECLARE @V_IDCONSCALVENNF VARCHAR(1);

   DECLARE @V_IDREFECALCPARC VARCHAR(30);
   DECLARE @V_DIASEMANA NUMERIC(1);
   DECLARE @V_IDCONSDIAUTIL VARCHAR(1);
   DECLARE @V_DTEMISSAOAUX DATETIME;

BEGIN
   SET @V_CDCLIEFORN = @P_CDCLIEFORN;
   /* DETERMINA O CDIGO PARA PESQUISA DOS DADOS PARA VENCIMENTO :
   0 - FORNECEDOR
   1 - CLIENTE
   2 - CONTRATO DE SERVIO
   3 - AUTORIZAO DE FORNECIMENTO
   4 - PEDIDO   */

   IF @P_IDENTRSAIDOP = 'E' BEGIN
      SET @V_CODIGO = '0';
   END
   ELSE BEGIN
      IF @P_IDENTRSAIDOP = 'S' BEGIN
         /*BUSCA O CONTRATO DE SERVIO RELACIONADO  NOTA*/
         SELECT @V_CDSERVCONT = MAX(CDSERVCONT)
           FROM SERVFATU
          WHERE (CDFILIAL   = @P_CDFILIAL) AND
                (NRLANCTONF = @P_NRLANCTONF);

         IF (@V_CDSERVCONT IS NULL) BEGIN
            SET @V_CODIGO = '1';
         END
         ELSE BEGIN
            SET @V_CODIGO = '2';
         END;
         /*VERIFICA SE  DEVOLUO AO FORNECEDOR*/
         IF @P_ORIGDESTNF = 'F' BEGIN
            /* BUSCA O CLIENTE RELACIONADO AO FORNECEDOR NO CADASTRO DE FORNECEDOR
             APENAS PARA NOTA DE DEVOLUO */
            SELECT @V_CDCLIEFORN = CDCLIENTE
              FROM FORNECEDOR
            WHERE CDFORNECED = @P_CDCLIEFORN;

            SET @V_CODIGO = '2';
         END;
      END
      ELSE BEGIN
         IF @P_IDENTRSAIDOP = 'A' BEGIN
            SET @V_CODIGO = '3';
         END
         ELSE BEGIN
            IF @P_IDENTRSAIDOP = 'P' BEGIN
               SET @V_CODIGO = '4';
            END;
         END;
      END;
   END;

   /* VERIFICA GERAO DE PARCELA DE SUBST. TRIBUTRIA*/
   IF (@V_CODIGO = '1') OR (@V_CODIGO = '4') BEGIN
      /*BUSCA SE EXISTE ALGUM IMPOSTO ACRESCER PARA GERAR PARCELA SEPARADA*/
      SELECT @V_COUNT = COUNT(1)
        FROM IMPOSNFTOT IT, IMPOSTO I
       WHERE IT.CDFILIAL     = @P_CDFILIAL
         AND IT.NRLANCTONF   = @P_NRLANCTONF
         AND IT.CDIMPOSTO    =  I.CDIMPOSTO
         AND I.IDTRATIMPO    = 'A'
         AND I.IDGERAPARCFIN = 'S';

      /*BUSCA  VALOR DO IMPOSTO ACRESCER PARA SOMAR NA PRIMEIRA PARCELA */
      SELECT @V_VRTOTIMPONFPR = ISNULL(SUM(N.VRTOTIMPONF), 0)
        FROM IMPOSNFTOT N, IMPOSTO I
       WHERE N.CDFILIAL    = @P_CDFILIAL
         AND N.NRLANCTONF  = @P_NRLANCTONF
         AND N.CDIMPOSTO   = I.CDIMPOSTO
         AND I.IDTRATIMPO  = 'A'
         AND IDGERAPARCFIN = 'P';
   END
   ELSE BEGIN
      SET @V_COUNT = 0;
   END;

   /*VALOR DA PARCELA DE SUBST. TRIBUTRIA*/
   SET @V_VRTOTIMPONF  = 0;
   SET @V_NRPARCELASST = 0;
   IF @V_COUNT > 0 BEGIN
      SELECT @V_VRTOTIMPONF     = ISNULL(N.VRTOTIMPONF, 0),
             @V_NRDIAPOSEMDOCST = MAX(NRDIASEMISDOC)
        FROM IMPOSNFTOT N, IMPOSTO I
       WHERE N.CDFILIAL    = @P_CDFILIAL
         AND N.NRLANCTONF  = @P_NRLANCTONF
         AND N.CDIMPOSTO   = I.CDIMPOSTO
         AND I.IDTRATIMPO  = 'A'
         AND IDGERAPARCFIN = 'S'
      GROUP BY N.VRTOTIMPONF;

         /*LANA VENCIMENTO PARA O VALOR DA SUBST. TRIBUTRIA*/
      IF NOT (@V_VRTOTIMPONF = 0) BEGIN
         SET @V_NRPARCELASST = 1;

         INSERT INTO TRAB_VENCIMENTO
           (CDFILIALVENC, NRLANCTONFVENC, DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC, IDTPCONTATRABVEN)
         VALUES
           (@P_CDFILIAL, @P_NRLANCTONF, (@P_DTEMISSAO + @V_NRDIAPOSEMDOCST), ROUND(@V_VRTOTIMPONF, 2), ISNULL(@V_NRDIAPOSEMDOCST, 0), RIGHT(REPLICATE('0', 5) + CONVERT(VARCHAR, @V_NRPARCELASST), 5), 'S');
      END;
   END;

   SET @V_INDIAS = 0;
   SET @V_DTVENCIMENTO = NULL;

   /*DETERMINA A DATA BASE E O NMERO DE DIAS APS A EMISSO*/
   /*###############################################SET PARMETROS##################################*/
   SELECT @V_IDFORMAPGTO    = IDTPFORPGT,
          @V_IDUTDIAPGT     = IDUTDIAPGT,
          @V_NRDIAPGFIX     = NRDIAPGFIX,
          @V_IDTIPODTPGT    = IDTIPODTPGT,
          @V_CDFORMPGTO     = CDFORMPGT,
          @V_IDTPPERIODO    = IDTPPERIODO,
          @V_NRPARCPGTO     = NRPARCPGTO,
          @V_IDREFECALCPARC = IDREFECALCPARC,
          @V_IDCONSDIAUTIL  = IDCONSDIAUTIL
     FROM
    (SELECT F.IDTPFORPGTFO IDTPFORPGT, F.IDUTDIAPGTFO IDUTDIAPGT, F.NRDIAPGFIXFO NRDIAPGFIX,
            FP.IDTIPODTPGTO IDTIPODTPGT, F.CDFORMPGTO CDFORMPGT, FP.IDTPPERIODO IDTPPERIODO,
            F.NRPARCPGTOFO NRPARCPGTO, FP.IDREFECALCPARC IDREFECALCPARC, FP.IDCONSDIAUTIL IDCONSDIAUTIL
       FROM FORNECEDOR F LEFT JOIN FORMPGTO FP
            ON (F.CDFORMPGTO = FP.CDFORMPGTO)
      WHERE (F.CDFORNECED = @V_CDCLIEFORN)
        AND (@V_CODIGO = '0')
      UNION
     SELECT C.IDTPFORPGTCL IDTPFORPGT, C.IDUTDIAPGTCL IDUTDIAPGT , C.NRDIAPGFIXCL NRDIAPGFIX ,
            FP.IDTIPODTPGTO IDTIPODTPGT, C.CDFORMPGTO CDFORMPGT, FP.IDTPPERIODO IDTPPERIODO,
            C.NRPARCPGTOCL NRPARCPGTO, FP.IDREFECALCPARC IDREFECALCPARC, FP.IDCONSDIAUTIL IDCONSDIAUTIL
       FROM CLIENTE C LEFT JOIN FORMPGTO FP
            ON (C.CDFORMPGTO = FP.CDFORMPGTO)
      WHERE (C.CDCLIENTE = @V_CDCLIEFORN)
        AND (@V_CODIGO = '1')
      UNION
     SELECT SC.IDTPFORPGTSC IDTPFORPGT, SC.IDUTDIAPGTSC IDUTDIAPGT, SC.NRDIAPGFIXSC NRDIAPGFIX,
            FP.IDTIPODTPGTO IDTIPODTPGT, SC.CDFORMPGTO CDFORMPGT, FP.IDTPPERIODO IDTPPERIODO,
            SC.NRPARCPGTOSC NRPARCPGTO, FP.IDREFECALCPARC IDREFECALCPARC, FP.IDCONSDIAUTIL IDCONSDIAUTIL
       FROM SERVCONTRAT SC LEFT JOIN FORMPGTO FP
            ON (SC.CDFORMPGTO = FP.CDFORMPGTO)
      WHERE (SC.CDCLIENTE  = @V_CDCLIEFORN)
        AND (SC.CDSERVCONT = @V_CDSERVCONT)
        AND (@V_CODIGO = '2')
      UNION
     SELECT A.IDTPFORPGTAF IDTPFORPGT, A.IDUTDIAPGTAF IDUTDIAPGT, A.NRDIAPGFIXAF NRDIAPGFIX,
            FP.IDTIPODTPGTO IDTIPODTPGT, A.CDFORMPGTO CDFORMPGT, FP.IDTPPERIODO IDTPPERIODO,
            NRPARCPGTOAF NRPARCPGTO, FP.IDREFECALCPARC IDREFECALCPARC, FP.IDCONSDIAUTIL IDCONSDIAUTIL
       FROM AUTOFORNE A LEFT JOIN FORMPGTO FP
            ON (A.CDFORMPGTO = FP.CDFORMPGTO)
      WHERE (A.CDFILDEST  = @P_CDFILDEST)
        AND (A.CDFILLANC  = @P_CDFILLANC)
        AND (A.NRAUTOFORN = @P_NRAUTOFORN)
        AND (@V_CODIGO = '3')
      UNION
     SELECT P.IDTPFORPGTPED IDTPFORPGT, P.IDUTDIAPAGPED IDUTDIAPGT, P.NRDIAPGFIXPED NRDIAPGFIX,
            FP.IDTIPODTPGTO IDTIPODTPGT, P.CDFORMPGTO CDFORMPGT, FP.IDTPPERIODO IDTPPERIODO,
            NRPARCPGTOPED NRPARCPGTO, FP.IDREFECALCPARC IDREFECALCPARC, FP.IDCONSDIAUTIL IDCONSDIAUTIL
       FROM PEDIDO P LEFT JOIN FORMPGTO FP
            ON (P.CDFORMPGTO = FP.CDFORMPGTO)
      WHERE (P.CDFILIAL   = @P_CDFILPEDIDO)
        AND (P.NRPEDIDO   = @P_NRPEDIDO)
        AND (@V_CODIGO = '4')) SS;

   IF NOT (@V_IDFORMAPGTO IS NULL) BEGIN
      IF @V_IDTPFORPGT = 'V' BEGIN
         /*QUANTIDADE DE PARCELAS*/
         SELECT @V_NRPARCELAS = MAX(QTPARCELAS)
           FROM
         (SELECT COUNT(*) AS QTPARCELAS
            FROM PRAZOPGTFORN
           WHERE CDFORNECED = @V_CDCLIEFORN
             AND @V_CODIGO = '0'
           UNION
          SELECT COUNT(*) AS QTPARCELAS
            FROM PRAZOPGTCLIE
           WHERE CDCLIENTE = @V_CDCLIEFORN
             AND @V_CODIGO = '1'
           UNION
          SELECT COUNT(*) AS QTPARCELAS
            FROM PZPGSERCONT
           WHERE CDCLIENTE = @P_CDCLIEFORN
             AND CDSERVCONT = @V_CDSERVCONT
             AND @V_CODIGO = '2'
           UNION
          SELECT COUNT(*) AS QTPARCELAS
            FROM PRAZOPGTAF
           WHERE CDFILDEST  = @P_CDFILDEST
             AND CDFILLANC  = @P_CDFILLANC
             AND NRAUTOFORN = @P_NRAUTOFORN
             AND @V_CODIGO = '3'
           UNION
          SELECT COUNT(*) AS QTPARCELAS
            FROM PRAZOPGTOPED
           WHERE CDFILIAL = @P_CDFILPEDIDO
             AND NRPEDIDO = @P_NRPEDIDO
             AND @V_CODIGO = '4') SS;
      END
      ELSE BEGIN
         SET @V_NRPARCELAS = @V_NRPARCPGTO;
      END;

      /*DETEMINA A DATA BASE E O NMERO DE DIAS A PARTIR DO TIPO DA FORMA DE PAGAMENTO E DO TIPO DA DATA DE PAGAMENTO*/
      IF NOT @V_IDFORMAPGTO IS NULL BEGIN
         IF @V_IDFORMAPGTO = 'V' BEGIN
            IF @V_IDTIPODTPGT = 'EMIN' BEGIN
               SET @V_INDIAS = 0;
               SET @V_DTBASE = @P_DTEMISSAO;
            END
            ELSE BEGIN
               IF @V_IDTIPODTPGT = 'EMEX' BEGIN
                  SET @V_INDIAS = 1;
                  SET @V_DTBASE = @P_DTEMISSAO;
               END
               ELSE BEGIN
                  IF @V_IDTIPODTPGT = 'ENIN' BEGIN
                     SET @V_INDIAS = 0;
                     SET @V_DTBASE = @P_DTENTRSAID;
                  END
                  ELSE BEGIN
                     IF @V_IDTIPODTPGT = 'ENEX' BEGIN
                        SET @V_INDIAS = 1;
                        SET @V_DTBASE = @P_DTENTRSAID;
                     END
                     ELSE BEGIN
                        IF @V_IDTIPODTPGT = 'DSIN' BEGIN
                           SET @V_INDIAS = 0;
                           SET @V_DTBASE = @P_DTENTRSAID;
                        END
                        ELSE BEGIN
                           IF @V_IDTIPODTPGT = 'DSEX' BEGIN
                              SET @V_INDIAS = 1;
                              SET @V_DTBASE = @P_DTENTRSAID;
                           END;
                        END;
                     END;
                  END;
               END;
            END;

            /* DETERMINA A DATA REFERNCIA DA FORMA DE PAGAMENTO */
            IF @V_IDREFECALCPARC = 'FORA_SEMANA' BEGIN
               SET @V_DIASEMANA = 8 - DATEPART(W,@V_DTBASE);
               SET @V_DTBASE = @V_DTBASE + @V_DIASEMANA;
            END
            ELSE BEGIN
               IF @V_IDREFECALCPARC = 'FORA_DEZENA' BEGIN
                  IF ((DAY(@V_DTBASE) >= 01) AND (DAY(@V_DTBASE) <= 10)) BEGIN
                     SET @V_DTBASE = CONVERT(DATETIME, '11/'+CONVERT(CHAR(4),MONTH(@V_DTBASE))+'/'+CONVERT(CHAR(4),YEAR(@V_DTBASE)), 103);
                  END
                  ELSE BEGIN
                     IF ((DAY(@V_DTBASE) >= 11) AND (DAY(@V_DTBASE) <= 20)) BEGIN
                        SET @V_DTBASE = CONVERT(DATETIME, '21/'+CONVERT(CHAR(4),MONTH(@V_DTBASE))+'/'+CONVERT(CHAR(4),YEAR(@V_DTBASE)), 103);
                     END
                     ELSE BEGIN
                        IF ((DAY(@V_DTBASE) >= 21) AND (DAY(@V_DTBASE) <= 31)) BEGIN
                           SET @V_DTBASE = CONVERT(DATETIME, '01/'+ MONTH(@V_DTBASE) + YEAR(@V_DTBASE), 103);
                           SET @V_DTBASE = DATEADD(MM, 1, @V_DTBASE);
                        END;
                     END;
                  END;
               END
               ELSE BEGIN
                  IF @V_IDREFECALCPARC = 'FORA_QUINZENA' BEGIN
                     IF ((DAY(@V_DTBASE) >= 01) AND (DAY(@V_DTBASE) <= 15)) BEGIN
                        SET @V_DTBASE = CONVERT(DATETIME, '16/'+CONVERT(CHAR(4),MONTH(@V_DTBASE))+'/'+CONVERT(CHAR(4),YEAR(@V_DTBASE)), 103);
                     END
                     ELSE BEGIN
                        IF ((DAY(@V_DTBASE) >= 16) AND (DAY(@V_DTBASE) <= 31)) BEGIN
                           SET @V_DTBASE = CONVERT(DATETIME, '01/'+ MONTH(@V_DTBASE) + YEAR(@V_DTBASE), 103);
                           SET @V_DTBASE = DATEADD(MM, 1, @V_DTBASE);
                        END;
                     END;
                  END;
                  ELSE BEGIN
                     IF @V_IDREFECALCPARC = 'FORA_MES' BEGIN
                        SET @V_DTBASE = CONVERT(DATETIME, '01/'+ MONTH(@V_DTBASE) + YEAR(@V_DTBASE), 103);
                        SET @V_DTBASE = DATEADD(MM, 1, @V_DTBASE);
                     END
                  END;
               END;
            END;

            SET @V_DTAUX = @V_DTBASE + @V_INDIAS;
            SET @V_DTAUX = @V_DTAUX - 1;
            /*SE FOR NOTA FISCAL DE SERVIO, CONSIDERA O DIA DE PAGAMENTO*/
            IF (@V_CODIGO = '2') AND NOT (@V_CDFORMPGTO IS NULL) BEGIN
               IF @V_IDTPPERIODO = 'M' BEGIN
                  SET @V_DTAUX = TEKNISA.DIAMES(@V_CDFORMPGTO,
                                        @V_DTAUX);
               END
               ELSE BEGIN
                  IF @V_IDTPPERIODO = 'S' BEGIN
                     SET @V_DTAUX = TEKNISA.DIASEMANA(@V_CDFORMPGTO,
                                              @V_DTAUX);
                  END
                  ELSE BEGIN
                     SET @V_DTAUX = TEKNISA.DIASEMANAMES(@V_CDFORMPGTO,
                                                 @V_DTAUX);
                  END;
               END;
            END;
         END
         ELSE BEGIN
            SET @V_DTBASE = @P_DTEMISSAO;
            IF NOT (@P_DTEMISSAO IS NULL) BEGIN
               /* FORMA FIXA Verifica se o numero informado no cadastro de forma de pagamento  maior
               ou igual ao dia da data de vencimento. Ou se o opo de gerar 1 parcela no proximo mes
               esteja marcada  */
               IF (@V_IDUTDIAPGT = 'I') BEGIN
                  IF (@V_NRDIAPGFIX >= DAY(@P_DTEMISSAO)) BEGIN
                     /* pega o maior dia do mes */
                     SET @V_INDIAS = CONVERT(DOUBLE PRECISION, DAY((DATEADD(MM,1, @P_DTEMISSAO)-DAY(@P_DTEMISSAO))));
                      /* Verifica se numero informado no cadastro de forma de pagamento 
                         maior que o ultimo dia do mes. */
                     /*Pega o maior dia do mes */
                     IF @V_NRDIAPGFIX > @V_INDIAS BEGIN
                        SET @V_DTAUX = (DATEADD(MM,1, @P_DTEMISSAO)-DAY(@P_DTEMISSAO));
                     END
                     ELSE BEGIN
                        /*Joga a data com o dia informado na parametrizcao */
                        SET @V_DTAUX = CONVERT(DATETIME, CONVERT(VARCHAR, @V_NRDIAPGFIX)+'/'+ CONVERT(VARCHAR, MONTH(@V_DTAUX)) +'/'+ CONVERT(VARCHAR, YEAR(@V_DTAUX)), 103);
                     END;
                  END
                  ELSE BEGIN
                     SET @V_DTAUX = DATEADD(MM, 1, @P_DTEMISSAO);

                     SET @V_INDIAS = CONVERT(DOUBLE PRECISION, DAY((@V_DTAUX-DAY(@V_DTAUX))));
                     IF @V_NRDIAPGFIX <= @V_INDIAS BEGIN
                        SET @V_DTAUX = CONVERT(DATETIME, CONVERT(VARCHAR, @V_NRDIAPGFIX)+'/'+ CONVERT(VARCHAR, MONTH(@V_DTAUX)) +'/'+ CONVERT(VARCHAR, YEAR(@V_DTAUX)), 103);
                     END
                     ELSE BEGIN
                        SET @V_DTAUX = (@V_DTAUX-DAY(@V_DTAUX));
                     END;
                  END;
               END
               ELSE BEGIN
                  SET @V_DTAUX = DATEADD(MM, 1, @P_DTEMISSAO);

                  SET @V_INDIAS = CONVERT(DOUBLE PRECISION, DAY((@V_DTAUX-DAY(@V_DTAUX))));
                  IF @V_NRDIAPGFIX <= @V_INDIAS BEGIN
                     SET @V_DTAUX = CONVERT(DATETIME, CONVERT(VARCHAR, @V_NRDIAPGFIX)+'/'+ CONVERT(VARCHAR, MONTH(@V_DTAUX)) +'/'+ CONVERT(VARCHAR, YEAR(@V_DTAUX)), 103);
                  END
                  ELSE BEGIN
                     SET @V_DTAUX = (@V_DTAUX-DAY(@V_DTAUX));
                  END;
               END;
            END
            ELSE BEGIN
               SET @V_DTAUX = @P_DTEMISSAO;
            END;
         END;
         SET @V_INGUARDANRDIAS = CONVERT(DOUBLE PRECISION, @V_DTAUX -@V_DTBASE);
         IF (@V_INGUARDANRDIAS IS NULL) BEGIN
            SET @V_INGUARDANRDIAS = 0;
         END;
      END;
   END
   ELSE BEGIN
      SET @V_INGUARDANRDIAS = 0;
      SET @V_DTBASE = @P_DTEMISSAO;
      SET @V_IDFORMAPGTO = NULL;
      SET @V_IDTIPODTPGT = NULL;
      SET @V_IDTPPERIODO = NULL;
      SET @V_NRPARCELAS  = 1;
      SET @V_NRPARCPGTO  = 1;
   END;



   /*################################################################################################*/
   IF (@V_IDCONSDIAUTIL = 'S') BEGIN
      SET @V_BOCONSFERIBANC = 1;
   END
   ELSE BEGIN
      SET @V_BOCONSFERIBANC = 0;
   END;

   /*ABATE A PARCELA DE IMPOSTO*/
   IF @V_VRTOTIMPONFPR IS NULL BEGIN
      SET @V_VRTOTIMPONFPR = 0;
   END;                          
   SET @V_VRPAGTO = ROUND(@P_VRPAGTO - @V_VRTOTIMPONF - @V_VRTOTIMPONFPR,2);

   IF @V_IDFORMAPGTO IS NULL BEGIN /* SEM FORMA DE PAGAMENTO*/
      SET @V_NRPARCELAS = 1;

      INSERT INTO TRAB_VENCIMENTO
         (CDFILIALVENC, NRLANCTONFVENC, DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC, IDTPCONTATRABVEN)
      VALUES
         (@P_CDFILIAL, @P_NRLANCTONF, @P_DTEMISSAO, ROUND(@V_VRPAGTO + @V_VRTOTIMPONFPR, 2), 0, RIGHT(REPLICATE('0',5)+CONVERT(VARCHAR,1 + @V_NRPARCELASST),5), 'N');
   END
   ELSE BEGIN
      IF (@V_IDFORMAPGTO = 'F') BEGIN /*FORMA DE PAGAMENTO FIXA*/
         SET @V_DTVENCIMENTO = @V_DTBASE + @V_INGUARDANRDIAS;
         SET @V_VRPARCVENC = ROUND(@V_VRPAGTO/@V_NRPARCPGTO,2);
         SET @V_SEQUENCIAL = 1;
         SET @V_NRPARCELAS = @V_NRPARCPGTO;
         /*LANA CONTAS PARA O MESMO DIA INDICADO PORM EM MESES DIFERENTES*/
         WHILE @V_SEQUENCIAL <= @V_NRPARCELAS BEGIN
            IF @V_SEQUENCIAL = @V_NRPARCELAS BEGIN
               SET @V_VRPARCVENC = @V_VRPARCVENC + ROUND(@V_VRPAGTO - (@V_VRPARCVENC * @V_NRPARCPGTO),2);
            END;
            /*INSERE OS DADOS DO VENCIMENTO*/
            INSERT INTO TRAB_VENCIMENTO
               (CDFILIALVENC, NRLANCTONFVENC, DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC, IDTPCONTATRABVEN)
            VALUES
               (@P_CDFILIAL, @P_NRLANCTONF, @V_DTVENCIMENTO, ROUND(CASE @V_SEQUENCIAL WHEN 1 THEN @V_VRPARCVENC+@V_VRTOTIMPONFPR ELSE @V_VRPARCVENC END, 2), ISNULL(CONVERT(DOUBLE PRECISION, @V_DTVENCIMENTO-@P_DTEMISSAO), 0), RIGHT(REPLICATE('0',5)+CONVERT(VARCHAR,@V_SEQUENCIAL + @V_NRPARCELASST),5), 'N');

            IF NOT (@V_DTVENCIMENTO IS NULL) BEGIN
               SET @V_DTVENCIMENTO = DATEADD(MM, 1, @V_DTVENCIMENTO);
            END;
            SET @V_SEQUENCIAL = @V_SEQUENCIAL + 1;
         END;
      END
      ELSE BEGIN/*FORMA DE PAGAMENTO VARIVEL*/
         SET @V_SEQUENCIAL = 1;
         SET @V_VRPARCAUXI = 0;

         DECLARE C_PARCELAS CURSOR FOR
         SELECT NRDIASPGTO, VRPERCPGTO
           FROM
         (SELECT ISNULL(NRDIASPGTOFO, 0) AS NRDIASPGTO, ISNULL(VRPERCPGTOFO, 100) VRPERCPGTO
           FROM PRAZOPGTFORN
          WHERE CDFORNECED = @V_CDCLIEFORN
            AND @V_CODIGO = '0'
          UNION
         SELECT ISNULL(NRDIASPGTOCL, 0) AS NRDIASPGTO, ISNULL(VRPERCPGTOCL, 100) VRPERCPGTO
           FROM PRAZOPGTCLIE
          WHERE CDCLIENTE = @V_CDCLIEFORN
            AND @V_CODIGO = '1'
          UNION
         SELECT ISNULL(NRDIASPGTOSC, 0) AS NRDIASPGTO, ISNULL(VRPERCPGTOSC, 100) VRPERCPGTO
           FROM PZPGSERCONT
          WHERE CDCLIENTE = @V_CDCLIEFORN
            AND CDSERVCONT = @V_CDSERVCONT
            AND @V_CODIGO = '2'
          UNION
         SELECT ISNULL(NRDIASPGTOAF, 0) AS NRDIASPGTO, ISNULL(VRPERCPGTOAF, 100) VRPERCPGTO
           FROM PRAZOPGTAF
          WHERE CDFILDEST = @P_CDFILDEST
            AND CDFILLANC  = @P_CDFILLANC
            AND NRAUTOFORN = @P_NRAUTOFORN
            AND @V_CODIGO = '3'
          UNION
         SELECT ISNULL(NRDIASPGTOPED, 0) AS NRDIASPGTO, ISNULL(VRPERCPGTOPED, 100) VRPERCPGTO
           FROM PRAZOPGTOPED
          WHERE CDFILIAL = @P_CDFILPEDIDO
            AND NRPEDIDO = @P_NRPEDIDO
            AND @V_CODIGO = '4') SS;
         OPEN C_PARCELAS;
         FETCH NEXT FROM C_PARCELAS INTO @V_NRDIASPGTO, @V_VRPERCPGTO;
         /*PARCELAS PARA GERAO DE TIPO DE PAGAMENTO VARIVEL*/
         WHILE (@@FETCH_STATUS = 0) BEGIN
            SET @V_VRPARCVENC = ROUND((@V_VRPAGTO * (@V_VRPERCPGTO/100)),2);
            SET @V_VRPARCAUXI = @V_VRPARCAUXI + @V_VRPARCVENC;

            IF @V_SEQUENCIAL = @V_NRPARCELAS BEGIN
               SET @V_VRPARCVENC = @V_VRPARCVENC + ROUND((@V_VRPAGTO - @V_VRPARCAUXI),2);
            END;

            IF @V_NRDIASPGTO = 0 BEGIN
               SET @V_INDIAS = @V_INGUARDANRDIAS +1;
            END
            ELSE BEGIN
               SET @V_INDIAS = @V_INGUARDANRDIAS + @V_NRDIASPGTO;
            END;

            IF NOT @V_DTBASE IS NULL BEGIN
               SET @V_DTVENCIMENTO = @V_DTBASE + @V_INDIAS;
            END;

            IF @V_BOCONSFERIBANC = 1 BEGIN
               SET @V_BOFERIFILI = 1;

               SELECT @V_IDCONSCALVENNF = IDCONSCALVENNF
                 FROM PARAMFILIAL
                WHERE CDFILIAL = @P_CDFILIEMIRECE;

            IF @V_IDTIPODTPGT = 'ENEX' OR @V_IDTIPODTPGT = 'DSEX' OR
               @V_IDTIPODTPGT = 'ENIN' OR @V_IDTIPODTPGT = 'DSIN' BEGIN
               SET @V_DTEMISSAOAUX = @P_DTENTRSAID;
            END
            ELSE BEGIN
               SET @V_DTEMISSAOAUX = @P_DTEMISSAO;
            END;

               /*CORRIGE A DATA DE VENCIMENTO CONSIDERANDO FERIADO BANCRIO*/
               WHILE @V_BOFERIFILI = 1 BEGIN
                  IF (@V_IDTIPODTPGT = 'EMEX') OR (@V_IDTIPODTPGT = 'ENEX') OR (@V_IDTIPODTPGT = 'DSEX') BEGIN
                     IF @V_IDCONSCALVENNF = 'F' BEGIN
                        SELECT @V_NRDIASFERI = COUNT(*)
                          FROM FERIFILI
                         WHERE CDFILIAL = @P_CDFILIEMIRECE
                           AND DTFERIFILI BETWEEN @V_DTEMISSAOAUX+1 AND @V_DTVENCIMENTO;
                     END
                     ELSE BEGIN
                        IF @V_IDCONSCALVENNF = 'C' BEGIN
                           SELECT @V_NRDIASFERI = COUNT(*)
                             FROM FERICOMP
                            WHERE CDFILIAL = @P_CDFILIEMIRECE
                              AND DTFERICOMP BETWEEN @V_DTEMISSAOAUX+1 AND @V_DTVENCIMENTO;
                        END
                        ELSE BEGIN
                           SELECT @V_NRDIASFERI = COUNT(*)
                             FROM FERIBANC
                            WHERE CDFILIAL = @P_CDFILIEMIRECE
                              AND DTFERIBANC BETWEEN @V_DTEMISSAOAUX+1 AND @V_DTVENCIMENTO;
                        END;
                     END;
                  END
                  ELSE BEGIN
                     IF @V_IDCONSCALVENNF = 'F' BEGIN
                        SELECT @V_NRDIASFERI = COUNT(*)
                          FROM FERIFILI
                         WHERE CDFILIAL = @P_CDFILIEMIRECE
                           AND DTFERIFILI BETWEEN @V_DTEMISSAOAUX AND @V_DTVENCIMENTO;
                     END
                     ELSE BEGIN
                        IF @V_IDCONSCALVENNF = 'C' BEGIN
                           SELECT @V_NRDIASFERI = COUNT(*)
                             FROM FERICOMP
                            WHERE CDFILIAL = @P_CDFILIEMIRECE
                              AND DTFERICOMP BETWEEN @V_DTEMISSAOAUX AND @V_DTVENCIMENTO;
                        END
                        ELSE BEGIN
                           SELECT @V_NRDIASFERI = COUNT(*)
                             FROM FERIBANC
                            WHERE CDFILIAL = @P_CDFILIEMIRECE
                              AND DTFERIBANC BETWEEN @V_DTEMISSAOAUX AND @V_DTVENCIMENTO;
                        END;
                     END;
                  END;

                  IF NOT(@V_NRDIASFERI = 0) BEGIN
                     SET @V_DTANTERIOR = @V_DTVENCIMENTO;
                     SET @V_DTVENCIMENTO = @V_DTVENCIMENTO + @V_NRDIASFERI;
                     WHILE @V_BOFERIFILI = 1 BEGIN
                        SET @V_DTANTERIOR = @V_DTANTERIOR+1;
                        IF @V_IDCONSCALVENNF = 'F' BEGIN
                           SELECT @V_NRDIASFERI = COUNT(*)
                             FROM FERIFILI
                            WHERE CDFILIAL = @P_CDFILIEMIRECE
                              AND DTFERIFILI BETWEEN @V_DTANTERIOR AND @V_DTVENCIMENTO;
                        END
                        ELSE BEGIN
                           IF @V_IDCONSCALVENNF = 'C' BEGIN
                              SELECT @V_NRDIASFERI = COUNT(*)
                                FROM FERICOMP
                               WHERE CDFILIAL = @P_CDFILIEMIRECE
                                 AND DTFERICOMP BETWEEN @V_DTANTERIOR AND @V_DTVENCIMENTO;
                           END
                           ELSE BEGIN
                              SELECT @V_NRDIASFERI = COUNT(*)
                                FROM FERIBANC
                               WHERE CDFILIAL = @P_CDFILIEMIRECE
                                 AND DTFERIBANC BETWEEN @V_DTANTERIOR AND @V_DTVENCIMENTO;
                           END;
                        END;

                        IF @V_NRDIASFERI > 0 BEGIN
                           SET @V_DTANTERIOR = @V_DTVENCIMENTO;
                           SET @V_DTVENCIMENTO = @V_DTVENCIMENTO + @V_NRDIASFERI;
                        END
                        ELSE BEGIN
                           SET @V_BOFERIFILI = 0;
                        END;
                     END;
                  END
                  ELSE BEGIN
                     SET @V_BOFERIFILI = 0;
                  END;
               END;
            END;

            /*CONSIDERA DIA DE PAGAMENTO. CASO FOR NOTA FISCAL DE SERVIO, O DIA DE PAGAMENTO J FOI CONSISTIDO ANTERIORMENTE*/
            IF NOT (@V_DTVENCIMENTO IS NULL) BEGIN
               IF @V_IDTPPERIODO = 'M' BEGIN
                  SET @V_DTVENCIMENTO = TEKNISA.DIAMES(@V_CDFORMPGTO,
                                               @V_DTVENCIMENTO);
               END
               ELSE BEGIN
                  IF @V_IDTPPERIODO = 'S' BEGIN
                     SET @V_DTVENCIMENTO = TEKNISA.DIASEMANA(@V_CDFORMPGTO,
                                                     @V_DTVENCIMENTO);
                  END
                  ELSE BEGIN
                     SET @V_DTVENCIMENTO = TEKNISA.DIASEMANAMES(@V_CDFORMPGTO,
                                                        @V_DTVENCIMENTO);
                  END;
               END;
            END;

            INSERT INTO TRAB_VENCIMENTO
               (CDFILIALVENC, NRLANCTONFVENC, DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC, IDTPCONTATRABVEN)
            VALUES
               (@P_CDFILIAL, @P_NRLANCTONF, @V_DTVENCIMENTO,ROUND(CASE @V_SEQUENCIAL WHEN 1 THEN @V_VRPARCVENC + @V_VRTOTIMPONFPR ELSE @V_VRPARCVENC END, 2), ISNULL(CONVERT(DOUBLE PRECISION,@V_DTVENCIMENTO-@P_DTEMISSAO), 0), RIGHT(REPLICATE('0', 5) + CONVERT(VARCHAR,@V_SEQUENCIAL + @V_NRPARCELASST), 5), 'N');

            SET @V_SEQUENCIAL = @V_SEQUENCIAL + 1;
            FETCH NEXT FROM C_PARCELAS INTO @V_NRDIASPGTO, @V_VRPERCPGTO;
         END;
         CLOSE C_PARCELAS;
         DEALLOCATE C_PARCELAS;
         IF @V_SEQUENCIAL = 1 BEGIN
            INSERT INTO TRAB_VENCIMENTO
               (CDFILIALVENC, NRLANCTONFVENC, DTVENCIMENTO, VRVENCIMENTO, QTDIASVENC, NRSEQVENC, IDTPCONTATRABVEN)
            VALUES
               (@P_CDFILIAL, @P_NRLANCTONF, @P_DTEMISSAO, ROUND(@V_VRPAGTO + @V_VRTOTIMPONFPR, 2), 0, RIGHT(REPLICATE('0',5)+CONVERT(VARCHAR,1 + @V_NRPARCELASST),5), 'N');
         END;
      END;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'CRIA_VENCIMENTO','5.60.xxx';
GO
